@@ -130,7 +130,7 @@ class Agent:
         start = time()
 
         # If an action is already set (uncleared), there is an error.
-        if self.message.action != None:
+        if self.message.action is not None:
             return self.message.action
 
         # Inform the agent an action is requested.
@@ -139,7 +139,7 @@ class Agent:
         if self.use_process:
             # Timeout or Action Returned (will be processed below).
             while True:
-                if time() - start > timeout or self.message.action != None:
+                if time() - start > timeout or self.message.action is not None:
                     break
         else:
             if self.agent is None:
