@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import traceback
 import copy
 import json
 from time import time
@@ -158,7 +159,7 @@ class Environment:
                 self.debug_print(f"Timeout: {str(action)}")
                 action_state[index]["status"] = "TIMEOUT"
             elif isinstance(action, BaseException):
-                self.debug_print(f"Error: {str(action)}")
+                self.debug_print(f"Error: {traceback.format_exception(None, action, action.__traceback__)}")
                 action_state[index]["status"] = "ERROR"
             else:
                 err, data = process_schema(
@@ -191,7 +192,7 @@ class Environment:
         Returns:
             list of list of dict: The agent states of all steps executed.
         """
-        if self.state == None or len(self.steps) == 1 or self.done:
+        if self.state is None or len(self.steps) == 1 or self.done:
             self.reset(len(agents))
         if len(self.state) != len(agents):
             raise InvalidArgument(
@@ -250,7 +251,6 @@ class Environment:
             out = self.renderer(*args[:self.renderer.__code__.co_argcount])
             if mode == "ansi":
                 return out
-            print(out)
         elif mode == "html" or mode == "ipython":
             window_kaggle = {
                 "debug": get(kwargs, bool, self.debug, path=["debug"]),
@@ -547,8 +547,12 @@ class Environment:
                 agents[i] = self.agents[agent]
 
         # Generate the agents.
-        agents = [Agent(a, self.configuration, self.name, debug=self.debug) if a !=
-                  None else None for a in agents]
+        agents = [
+            Agent(a, self.configuration, self.name, debug=self.debug)
+            if a is not None
+            else None
+            for a in agents
+        ]
 
         # Have the agents had a chance to initialize (first non-empty act).
         initialized = [False] * len(agents)
