@@ -63,7 +63,7 @@ class Point(tuple):
     def __floordiv__(self, denominator: int) -> 'Point':
         return self.map(lambda x: x // denominator)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash((self.x, self.y))
 
     def __mod__(self, mod: int) -> 'Point':
@@ -231,6 +231,7 @@ class ShipAction(Enum):
     SOUTH = auto()
     WEST = auto()
     CONVERT = auto()
+    # Use None to collect halite on a cell
 
     def to_point(self) -> Optional[Point]:
         """
@@ -472,7 +473,7 @@ class Player:
     @property
     def is_current_player(self) -> bool:
         """Returns whether this player is the current player (generally if this returns True, this player is you)."""
-        return self.id is self._board.current_player_id
+        return self.id == self._board.current_player_id
 
     @property
     def next_actions(self) -> Dict[str, str]:
@@ -501,8 +502,8 @@ class Player:
 class Board:
     def __init__(
         self,
-        raw_observation: Dict[str, any],
-        raw_configuration: Union[Configuration, Dict[str, any]],
+        raw_observation: Dict[str, Any],
+        raw_configuration: Union[Configuration, Dict[str, Any]],
         next_actions: Optional[List[Dict[str, str]]] = None
     ) -> None:
         """
@@ -712,7 +713,7 @@ class Board:
         def create_uid():
             nonlocal uid_counter
             uid_counter += 1
-            return f"{self.step}-{uid_counter}"
+            return f"{self.step + 1}-{uid_counter}"
 
         # Process actions and store the results in the ships and shipyards lists for collision checking
         for player in board.players.values():
